@@ -18,6 +18,9 @@
 #' @return Dropped for each distance matrix and object of class "na.action" 
 #' containing indices to those indivudals in the genind object which where 
 #' omitted due to having NAs
+#' @importFrom stats dist
+#' @importFrom stats na.omit
+#' @importFrom stats complete.cases
 #' @export
 #' 
 #' @references
@@ -34,6 +37,10 @@ dist.codom <- function(x, matrix=TRUE, global=TRUE, na.rm=TRUE){
   
 
   per.loc <- function(l){
+    ploidy <- unique(l@ploidy) 
+    if(length(ploidy) > 1){
+        stop("All samples must have sample ploidy for dist.codom")
+    }
 	if(na.rm){ 
 	  l@tab <- na.omit(l@tab)
 	  dropped <- attr(l@tab, "na.action") 
@@ -41,7 +48,7 @@ dist.codom <- function(x, matrix=TRUE, global=TRUE, na.rm=TRUE){
     else{
         dropped <- NULL
     }
-	res <- dist(l@tab, "manhattan") / l@ploidy
+	res <- dist(l@tab/ploidy, "manhattan")/2
 	if(matrix){
 	    res <- as.matrix(res)
         }
